@@ -35,10 +35,10 @@ if (!isGeneric("demom")) {
 
 
 if (!isGeneric("postProb")) {
-  setGeneric("postProb", function(object, nmax) standardGeneric("postProb"))
+  setGeneric("postProb", function(object, nmax, method='norm') standardGeneric("postProb"))
 }
 
 if (!isGeneric("rnlp")) {
-  setGeneric("rnlp", function(y, x, m, V, msfit, priorCoef, priorVar=igprior(alpha=0.01,lambda=0.01), niter=10^3, burnin=round(niter/10), thinning=1) standardGeneric("rnlp"))
+  setGeneric("rnlp", function(y, x, m, V, msfit, priorCoef, priorVar=igprior(alpha=0.01,lambda=0.01), niter=10^3, burnin=round(niter/10), thinning=1, pp='norm') standardGeneric("rnlp"))
 }
 
